@@ -36,13 +36,11 @@
 
 using namespace LIFEO;
 
-AppWindow* AppWindow::p = NULL;
+AppWindow* AppWindow::p = nullptr;
 
 // CONSTRUCTOR
-AppWindow::AppWindow()
-:   m_view_login( NULL ), m_diary_view( NULL ), m_entry_view( NULL ), m_tag_view( NULL ),
-    m_ctg_tags_view( NULL ), m_chapter_view( NULL ), m_about_dialog( NULL ), m_paned_main( NULL ),
-    m_seconds_remaining( LOGOUT_COUNTDOWN + 1 ), m_auto_logout_status( 1 )
+AppWindow::AppWindow( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& b )
+:   Gtk::ApplicationWindow( cobject )
 {
     p = this;
 
@@ -60,19 +58,11 @@ AppWindow::AppWindow()
     if( Lifeograph::settings.state_maximized )
         maximize();
 
-    // GTKBUILDER
-    Lifeograph::p->load_gui( UIDIR "/lifeograph.ui" );
-
-    // HEADERBAR
-    m_headerbar.set_show_close_button();
-
-    // Set headerbar as titlebar
-    set_titlebar( m_headerbar );
-    m_headerbar.show();
-
     // DRAW UI
     try
     {
+        Lifeograph::builder->get_widget( "Hb_main", m_Hb_main );
+        Lifeograph::builder->get_widget( "St_main", m_St_main );
         m_view_login = new ViewLogin;
         m_view_login->handle_start();
     }
@@ -328,7 +318,10 @@ AppWindow::logout( bool opt_save )
 
     Lifeograph::p->m_flag_open_directly = false;   // should be reset to prevent logging in again
     if( finish_editing( opt_save ) )
+    {
         m_view_login->handle_logout();
+        m_St_main->set_visible_child( "login" );
+    }
 
     m_auto_logout_status = 1;
 }
@@ -342,7 +335,7 @@ AppWindow::confirm_dismiss_element( const DiaryElement* elem, Gtk::Widget* extra
             Glib::ustring::compose( _( "Are you sure, you want to dismiss %1?" ),
                                     Glib::ustring::compose( "\"%1\"", elem->get_name() ) ) );
     message.set_secondary_text( _( "This operation cannot be undone!" ) );
-    message.add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
+    message.add_button( _( "_Cancel" ), Gtk::RESPONSE_CANCEL );
     message.add_button( _( "_DISMISS!" ), Gtk::RESPONSE_ACCEPT );
 
     if( extra_widget )
@@ -394,8 +387,6 @@ AppWindow::update_title()
 void
 AppWindow::login()
 {
-    remove();
-
     if( m_paned_main == NULL )
     {
 #ifdef LIFEO_NO_APP_MENU
@@ -407,8 +398,8 @@ AppWindow::login()
         {
             // GENERAL TOOLS
 #ifdef LIFEO_NO_APP_MENU
-            Lifeograph::builder->get_widget( "menuitem_preferences", menuitem_preferences );
-            Lifeograph::builder->get_widget( "menuitem_about", menuitem_about );
+            Lifeograph::builder->get_widget( "MI_preferences", menuitem_preferences );
+            Lifeograph::builder->get_widget( "MI_about", menuitem_about );
 #endif
 
             // PANES
@@ -416,7 +407,7 @@ AppWindow::login()
             Lifeograph::builder->get_widget( "P_second", m_paned_entry );
 
             // TAG PANEL
-            Lifeograph::builder->get_widget_derived( "treeview_all_tags", panel_extra );
+            Lifeograph::builder->get_widget_derived( "TV_all_tags", panel_extra );
 
             // ICONS
             std::string icon_dir( ICONDIR );
@@ -426,6 +417,9 @@ AppWindow::login()
                 icon_dir += Lifeograph::settings.icon_theme;
             }
 
+            Glib::RefPtr< Gtk::IconTheme > theme = Gtk::IconTheme::get_default();
+            theme->append_search_path( icon_dir );
+
             Lifeograph::icons->diary_16 =
                     Gdk::Pixbuf::create_from_file( icon_dir + "/diary-16.png" );
             Lifeograph::icons->diary_32 =
@@ -464,12 +458,10 @@ AppWindow::login()
             Lifeograph::icons->month_32 =
                     Gdk::Pixbuf::create_from_file( icon_dir + "/month-32.png" );
 
-            Lifeograph::icons->filter_16 =
-                    Gdk::Pixbuf::create_from_file( icon_dir + "/filter-16.png" );
-            Lifeograph::icons->filter_32 =
-                    Gdk::Pixbuf::create_from_file( icon_dir + "/filter-32.png" );
-            Lifeograph::icons->filter_revert_16 =
-                    Gdk::Pixbuf::create_from_file( icon_dir + "/filter_revert-16.png" );
+            Gtk::IconInfo ii = theme->lookup_icon( "filter-16-symbolic", 16 );
+            bool res;
+            Lifeograph::icons->filter_16 = ii.load_symbolic( m_paned_main->get_style_context(),
+                                                             res );
 
             Lifeograph::icons->todo_open_16 =
                     Gdk::Pixbuf::create_from_file( icon_dir + "/todo_open-16.png" );
@@ -489,15 +481,14 @@ AppWindow::login()
                     Gdk::Pixbuf::create_from_file( icon_dir + "/todo_canceled-32.png" );
 
             // PANELS & VIEWS
+            m_filter_view = new FilterView; // this is needed by PanelDiary
             panel_main = new PanelMain;
             panel_diary = new PanelDiary;
-            //panel_extra = new PanelExtra;
             m_diary_view = new DiaryView;
             m_ctg_tags_view = new CategoryTagsView;
             m_chapter_view = new ChapterView;
             m_entry_view = new EntryView;
             m_tag_view = new TagView;
-            m_filter_view = new FilterView;
         }
         catch( std::exception &ex )
         {
@@ -552,7 +543,7 @@ AppWindow::login()
     Lifeograph::m_actions_edit->set_visible( Diary::d->is_read_only() == false );
     Lifeograph::m_actions_edit->set_sensitive( Diary::d->is_read_only() == false );
 
-    add( *m_paned_main );
+    m_St_main->set_visible_child( *m_paned_main );
 
     // LOGIN
     // the following must come before handle_login()s
