@@ -36,7 +36,7 @@ static const char LANG_INHERIT_DIARY[] = "d";
 class Entry : virtual public DiaryElement
 {
     public:
-        static ElementShower< Entry >* shower;
+        static ElementView< Entry >* shower;
 
 #ifndef LIFEO_WINDOZE
         typedef sigc::signal< void, Entry* >
@@ -49,15 +49,16 @@ class Entry : virtual public DiaryElement
                                        bool = false );
         virtual                 ~Entry() {}
 
-        void                    show();
-        void                    prepare_for_hiding();
+        void                    show() override;
+        void                    prepare_for_hiding() override;
 
         const Ustring*          get_text() const { return &m_text; }
         Ustring&                get_text() { return m_text; }
         void                    set_text( const Ustring& text )
         { m_text = text; calculate_title( text ); }
+        void                    append_text( const Ustring& text );
 
-        Date                    get_date() const { return m_date; }
+        Date                    get_date() const override { return m_date; }
         void                    set_date( Date::date_t date )
         { m_date.m_date = date; }
 
@@ -72,23 +73,23 @@ class Entry : virtual public DiaryElement
         Ustring                 get_date_status_str() const;
         void                    set_date_status( Date::date_t d ) { m_date_status = d; }
 
-        int                     get_size() const
+        int                     get_size() const override
         { return m_text.size(); }
-        Type                    get_type() const
+        Type                    get_type() const override
         { return ET_ENTRY; }
 
 #ifndef LIFEO_WINDOZE
-        const Icon&             get_icon() const;
-        const Icon&             get_icon32() const;
+        const Icon&             get_icon() const override;
+        const Icon&             get_icon32() const override;
 #else
         int                     get_icon() const;
 #endif
 
         void                    calculate_title( const Ustring& );
 
-        Ustring                 get_list_str() const;
+        Ustring                 get_list_str() const override;
 
-        bool                    get_filtered_out();
+        bool                    get_filtered_out() override;
         void                    set_filtered_out( bool filteredout = true )
         {
             if( filteredout )
@@ -97,7 +98,7 @@ class Entry : virtual public DiaryElement
                 m_status -= ES::FILTERED_OUT;
         }
 
-        bool                    is_favored() const { return( m_status & ES::FAVORED ); }
+        bool                    is_favored() const override { return( m_status & ES::FAVORED ); }
         void                    set_favored( bool favored )
         {
             m_status -= ( m_status & ES::FILTER_FAVORED );
@@ -110,6 +111,11 @@ class Entry : virtual public DiaryElement
         std::string             get_lang_final() const;
         void                    set_lang( const std::string& lang ) { m_option_lang = lang; }
 
+        bool                    is_empty() const
+        {
+            return( m_text.empty() && m_tags.empty() );
+        }
+
         bool                    is_trashed() const { return( m_status & ES::TRASHED ); }
         void                    set_trashed( bool trashed )
         {
@@ -117,10 +123,13 @@ class Entry : virtual public DiaryElement
             m_status |= ( trashed ? ES::TRASHED : ES::NOT_TRASHED );
         }
 
-        void                    set_tags( const Tagset& );
-        const Tagset&           get_tags() const;
-        Tagset&                 get_tags();
-        bool                    add_tag( Tag* );
+        void                    set_tags( const TagSet& tags )
+        { m_tags = tags; }
+        const TagSet&           get_tags() const
+        { return m_tags; }
+        TagSet&                 get_tags()
+        { return m_tags; }
+        bool                    add_tag( Tag*, Value = 1.0 );
         bool                    remove_tag( Tag* );
         bool                    clear_tags();
 
@@ -139,10 +148,11 @@ class Entry : virtual public DiaryElement
         time_t                  m_date_edited;
         time_t                  m_date_status;
         Ustring                 m_text;
-        Tagset                  m_tags;
-        const Tag*              m_ptr2theme_tag; // NULL means theme is not set
+        TagSet                  m_tags;
+        Ustring                 m_location;
+        const Tag*              m_ptr2theme_tag{ nullptr }; // nullptr means theme is not set
 
-        std::string             m_option_lang;  // empty means off
+        std::string             m_option_lang = LANG_INHERIT_DIARY;  // empty means off
 
     friend class Diary; // TODO: remove this friendship too??
 };
@@ -151,11 +161,11 @@ class Entry : virtual public DiaryElement
 class PoolEntries : public std::map< Date::date_t, Entry*, FuncCompareDates >
 {
     public:
-                                    PoolEntries()
-        :   std::map< Date::date_t, Entry*, FuncCompareDates >( compare_dates ) {}
-                                    ~PoolEntries();
+                                PoolEntries()
+    :   std::map< Date::date_t, Entry*, FuncCompareDates >( compare_dates ) {}
+                                ~PoolEntries();
 
-        void                        clear();
+        void                    clear();
 };
 
 typedef PoolEntries::iterator               EntryIter;
