@@ -48,11 +48,10 @@ Error::Error( const Ustring& error_message )
 }
 
 // DATE ============================================================================================
-std::string Date::s_date_format_order = "YMD";
-char        Date::s_date_format_separator = '.';
+std::string Date::s_format_order = "YMD";
+char        Date::s_format_separator = '.';
 
 Date::Date( const std::string& str_date )
-:   m_date( 0 )
 {
     if( parse_string( &m_date, str_date ) != OK )
         m_date = NOT_SET;
@@ -158,7 +157,7 @@ Date::parse_string( Date::date_t* date, const Ustring& str_date )
         {
             if( num[ 0 ] <= 12 && num[ 1 ] <= 12 ) // both DMY and MDY possible
             {
-                if( s_date_format_order[ 0 ] == 'M' )
+                if( s_format_order[ 0 ] == 'M' )
                 {
                     month = num[ 0 ];
                     day = num[ 1 ];
@@ -226,9 +225,26 @@ Date::format_string( const date_t d, const std::string& format, const char separ
     }
     else
     {
-        result << std::setfill( '0' ) << std::setw( 2 ) << get_YMD( d, format[ 0 ] ) << separator
-               << std::setfill( '0' ) << std::setw( 2 ) << get_YMD( d, format[ 1 ] ) << separator
-               << std::setfill( '0' ) << std::setw( 2 ) << get_YMD( d, format[ 2 ] );
+        auto get_YMD = [ &d ]( char c ) -> unsigned int
+            {
+                switch( c )
+                {
+                    case 'Y':
+                        return get_year( d );
+                    case 'M':
+                        return get_month( d );
+                    case 'D':
+                    default: // no error checking for now
+                        return get_day( d );
+                }
+            };
+
+        for( unsigned int i = 0; i < format.size(); i++ )
+        {
+            result << std::setfill( '0' ) << std::setw( 2 ) << get_YMD( format[ i ] );
+            if( i != format.size() - 1 )
+                result << separator;
+        }
     }
     return result.str();
 }
@@ -271,8 +287,8 @@ Date::get_month_str() const
 }
 #endif
 
-Ustring
-Date::get_weekday_str() const
+int
+Date::get_weekday() const
 {
     // from wikipedia: http://en.wikipedia.org/wiki/Calculating_the_day_of_the_week
     const unsigned int year = get_year();
@@ -282,18 +298,14 @@ Date::get_weekday_str() const
     y = y + floor( y / 4 );
 
     static const int t_m[] = { 0, 3, 3, 6, 1, 4, 6, 2, 5, 0, 3, 5 };
-    struct tm ti;
 
     int m = get_month() - 1;
     int d = ( c + y + t_m[ m ] + get_day() );
 
-    if( !( get_year() % 4 ) && m < 2 )  // leap year!
+    if( m < 2 && is_leap_year() )  // leap year!
         d += 6;
 
-    ti.tm_wday = ( d % 7 );
-    char buf[ 32 ];
-    strftime( buf, 32, "%A", &ti );
-    return Ustring( buf );
+    return( d % 7 );
 }
 
 unsigned int
@@ -329,25 +341,7 @@ Date::get_ctime( const Date::date_t d )
 void
 Date::forward_months( int months )
 {
-    months += ( ( m_date & MONTH_FILTER ) >> 15 ); // get month
-    m_date &= YEAR_FILTER;   // isolate year
-    const int mod_months = months % 12;
-    if( mod_months == 0 )
-    {
-        m_date += make_year( ( months / 12 ) - 1);
-        m_date |= 0x60000;  // make month 12
-    }
-    else
-    {
-        m_date += make_year( months / 12 );
-        m_date |= make_month( mod_months );
-    }
-}
-
-void
-Date::forward_month()
-{
-    int months = get_month() + 1;
+    months += get_month();
     m_date &= YEAR_FILTER;   // isolate year
     const int mod_months = months % 12;
     if( mod_months == 0 )
@@ -369,7 +363,7 @@ Date::forward_day()
     if( day >= get_days_in_month() )
     {
         set_day( 1 );
-        forward_month();
+        forward_months( 1 );
     }
     else
         set_day( day + 1 );
@@ -397,23 +391,19 @@ Date::calculate_months_between( Date::date_t date2 ) const
 unsigned int
 Date::calculate_months_between( Date::date_t date1, Date::date_t date2 )
 {
-    int dist( 12 * ( get_year( date2 ) - get_year( date1 ) - 1 ) );
-    dist += ( 12 - get_month( date1 ) + get_month( date2 ) );
+    int dist{ 12 * int( get_year( date2 ) - get_year( date1 ) ) };
+    dist += ( get_month( date2 ) - get_month( date1 ) );
 
     return( dist < 0 ? -dist : dist );
 }
 
-// CONSOLE MESSAGES ================================================================================
-void
-print_error( const Ustring& description )
+int
+Date::calculate_months_between_neg( Date::date_t date1, Date::date_t date2 )
 {
-    std::cerr << "ERROR: " << description << std::endl;
-}
+    int dist{ 12 * int( get_year( date2 ) - get_year( date1 ) ) };
+    dist += ( get_month( date2 ) - get_month( date1 ) );
 
-void
-print_info( const Ustring& description )
-{
-    std::cout << "INFO: " << description << std::endl;
+    return dist;
 }
 
 // COLOR OPERATIONS ================================================================================
@@ -632,7 +622,7 @@ convert_utf8_to_16( const Ustring& str8 )
 char*
 convert_utf16_to_8( const wchar_t* str16 )
 {
-    char* str8;
+    char* str8{ nullptr };
     int size = WideCharToMultiByte( CP_UTF8, 0, str16, -1, str8, 0, NULL, NULL );
     str8 = new char[ size ];
     WideCharToMultiByte( CP_UTF8, 0, str16, -1, str8, size, NULL, NULL );
@@ -683,7 +673,7 @@ command_line_to_argvA( PCHAR CmdLine, int* _argc )
     i = 0;
     j = 0;
 
-    while( a = CmdLine[i] ) {
+    while( ( a = CmdLine[i] ) ) {
         if(in_QM) {
             if(a == '\"') {
                 in_QM = FALSE;
@@ -1002,15 +992,13 @@ EntryClear::on_changed()
     }
     else
     {
-        try
+        try // may not work!
         {
-            set_icon_from_pixbuf(
-                    Gtk::IconTheme::get_default()->load_icon( "edit-clear-symbolic", 16 ),
-                    Gtk::ENTRY_ICON_SECONDARY );
+            set_icon_from_icon_name( "edit-clear-symbolic", Gtk::ENTRY_ICON_SECONDARY );
         }
         catch( ... )
         {
-            set_icon_from_stock( Gtk::Stock::CLEAR, Gtk::ENTRY_ICON_SECONDARY );
+            set_icon_from_icon_name( "edit-clear", Gtk::ENTRY_ICON_SECONDARY );
         }
         set_icon_activatable( true, Gtk::ENTRY_ICON_SECONDARY );
     }
