@@ -33,14 +33,15 @@
 #include <sstream>
 #include <set>
 
-#include <gcrypt.h>
-
 #ifndef LIFEO_WINDOZE
 #include <gtkmm.h>
 #else
+#include<winsock2.h>    // to silence the compiler
 #include <shlwapi.h>
 #endif
 
+#include <gcrypt.h>
+
 #ifndef LIFEO_WINDOZE
 typedef Glib::ustring Ustring;
 typedef Glib::ustring Wstring;
@@ -61,7 +62,6 @@ typedef std::string Color;
 namespace HELPERS
 {
 
-#ifdef LIFEO_WINDOZE
 class STR
 {
     private:
@@ -85,7 +85,6 @@ class STR
             return str.str();
         }
 };
-#endif
 
 class Error
 {
@@ -168,8 +167,8 @@ class Date
         static const unsigned long  TOPIC_MIN           = VISIBLE_FLAG|ORDINAL_FLAG;
         static const unsigned long  GROUP_MIN           = ORDINAL_FLAG;
 
-        static std::string          s_date_format_order;
-        static char                 s_date_format_separator;
+        static std::string          s_format_order;
+        static char                 s_format_separator;
 
         typedef unsigned long date_t;
 
@@ -228,25 +227,20 @@ class Date
         { return ( ( m_date & YEAR_FILTER ) >> 19 ); }
         static unsigned int         get_year( const date_t d )
         { return ( ( d & YEAR_FILTER ) >> 19 ); }
-        
-        static int get_YMD( long d, char c )
-        {
-            switch( c )
-            {
-                case 'Y':
-                    return get_year( d );
-                case 'M':
-                    return get_month( d );
-                case 'D':
-                default: // no error checking for now
-                    return get_day( d );
-            }
-        }
+
+        int                         get_weekday() const;
 
         std::string                 get_year_str() const;
         Ustring                     get_month_str() const;
         //std::string                 get_day_str() const;
-        Ustring                     get_weekday_str() const;
+        Ustring                     get_weekday_str() const
+        {
+            struct tm ti;
+            ti.tm_wday = get_weekday();
+            char buf[ 32 ];
+            strftime( buf, 32, "%A", &ti );
+            return Ustring( buf );
+        }
 
         unsigned int                get_days_in_month() const;
 
@@ -257,10 +251,8 @@ class Date
                 return true;
             else if( ( year % 100 ) == 0 )
                 return false;
-            else if( ( year % 4 ) == 0 )
-                return true;
 
-            return false;
+            return( ( year % 4 ) == 0 );
         }
 
         unsigned int                get_month() const
@@ -333,9 +325,12 @@ class Date
         static Result               parse_string( Date::date_t*, const Ustring& );
 
         Ustring                     format_string() const
-        { return format_string( m_date, s_date_format_order, s_date_format_separator ); }
+        { return format_string( m_date, s_format_order, s_format_separator ); }
+        Ustring                     format_string( const std::string& format,
+                                                   const char separator = s_format_separator )
+        { return format_string( m_date, format, separator ); }
         static Ustring              format_string( const date_t date )
-        { return format_string( date, s_date_format_order, s_date_format_separator ); }
+        { return format_string( date, s_format_order, s_format_separator ); }
         static Ustring              format_string( const date_t, const std::string&, const char );
         static Ustring              format_string_dt( const time_t );
         static Ustring              format_string_d( const time_t );
@@ -357,8 +352,9 @@ class Date
         static bool                 is_hidden( const date_t d )
         { return( is_ordinal( d ) && !( d & VISIBLE_FLAG ) ); }
 
+        void                        forward_years( int years )
+        { m_date += make_year( years ); }
         void                        forward_months( int months );
-        void                        forward_month();
         void                        forward_day();
 
         void                        backward_ordinal_order()
@@ -394,9 +390,10 @@ class Date
         unsigned int                calculate_days_between( const Date& ) const;
         unsigned int                calculate_months_between( Date::date_t ) const;
         static unsigned int         calculate_months_between( Date::date_t, Date::date_t );
+        static int                  calculate_months_between_neg( Date::date_t, Date::date_t );
 
     //protected:
-        date_t                      m_date;
+        date_t                      m_date{ 0 };
 };
 
 /*
@@ -416,22 +413,55 @@ compare_dates( const Date::date_t& date_l, const Date::date_t& date_r )
 
 typedef bool( *FuncCompareDates )( const Date::date_t&, const Date::date_t& ) ;
 
-// CONSOLE MESSAGES ================================================================================
-void                print_error( const Ustring& );
-void                print_info( const Ustring& );
+// VALUES ==========================================================================================
+typedef double Value;
 
-#if LIFEOGRAPH_DEBUG_BUILD
-#define PRINT_DEBUG( msg )  std::cout << "DEBUG: " << msg << std::endl
-#define PRINT_DEBUG2( a1, a2 )  std::cout << "DEBUG: " << a1 << a2 << std::endl
-#define PRINT_DEBUG3( a1, a2, a3 )  std::cout << "DEBUG: " << a1 << a2 << a3 << std::endl
-#define PRINT_DEBUG4( a1, a2, a3, a4 )  std::cout << "DEBUG: " << a1 << a2 << a3 << a4 << std::endl
-#define PRINT_DEBUG5( a1, a2, a3, a4, a5 )  std::cout << "DEBUG: " << a1 << a2 << a3 << a4 << a5 << std::endl
+// CONSOLE MESSAGES ================================================================================
+class Console
+{
+    private:
+        static void print( std::ostream& os )
+        {
+            os << std::endl;
+        }
+
+        template< typename Arg1, typename... Args >
+        static void print( std::ostream& os, Arg1 arg1, Args... args )
+        {
+            os << arg1;
+            print( os, args... );
+        }
+
+    template< typename... Args >
+    friend void print_error( Args... );
+
+    template< typename... Args >
+    friend void print_info( Args... );
+
+    template< typename... Args >
+    friend void PRINT_DEBUG( Args... );
+};
+
+template< typename... Args >
+void print_info( Args... args )
+{
+    Console::print( std::cout, "INFO: ", args... );
+}
+
+template< typename... Args >
+void print_error( Args... args )
+{
+    Console::print( std::cerr, "ERROR: ", args... );
+}
+
+#ifdef LIFEOGRAPH_DEBUG_BUILD
+    template< typename... Args >
+    void PRINT_DEBUG( Args... args )
+    {
+        Console::print( std::cout, "* DBG *  ", args... );
+    }
 #else
-#define PRINT_DEBUG( msg )  ;
-#define PRINT_DEBUG2( a1, a2 )  ;
-#define PRINT_DEBUG3( a1, a2, a3 )  ;
-#define PRINT_DEBUG4( a1, a2, a3, a4 )  ;
-#define PRINT_DEBUG5( a1, a2, a3, a4, a5 )  ;
+#define PRINT_DEBUG( ... ) ;
 #endif
 
 // COLOR OPERATIONS ================================================================================
