@@ -33,7 +33,7 @@
 using namespace LIFEO;
 
 // STATIC MEMBERS
-const char                          Lifeograph::PROGRAM_VERSION_STRING[] = "1.3.0"
+const char                          Lifeograph::PROGRAM_VERSION_STRING[] = "1.4.0"
 #if LIFEOGRAPH_DEBUG_BUILD
         "\n" BUILD_TIMESTAMP
 #endif
@@ -59,9 +59,7 @@ std::string                         Lifeograph::s_color_insensitive;
 // CONSTRUCTOR
 Lifeograph::Lifeograph()
 :   Gtk::Application( "lifeograph.app",
-                      Gio::APPLICATION_NON_UNIQUE | Gio::APPLICATION_HANDLES_COMMAND_LINE ),
-    m_flag_force_welcome( false ),  m_flag_open_directly( false ),
-    m_flag_read_only( false )
+                      Gio::APPLICATION_NON_UNIQUE | Gio::APPLICATION_HANDLES_COMMAND_LINE )
 {
     p = this;
 
@@ -166,12 +164,15 @@ Lifeograph::on_startup()
     m_menu->append( _( "Quit" ), "app.quit" );
 
     set_app_menu( m_menu );
+
+    load_gui( UIDIR "/lifeograph.ui" );
 }
 
 void
 Lifeograph::on_activate()
 {
-    add_window( *( new AppWindow ) );
+    Lifeograph::builder->get_widget_derived( "W_main", AppWindow::p );
+    add_window( * AppWindow::p );
     AppWindow::p->show();
 }
 
@@ -224,7 +225,7 @@ Lifeograph::on_command_line( const Glib::RefPtr< Gio::ApplicationCommandLine >&
         }
         else
         {
-            print_info( std::string( "Unrecognized argument: " ) + argv[ i ] );
+            print_info( "Unrecognized argument: ", argv[ i ] );
         }
     }
 
@@ -243,12 +244,12 @@ Lifeograph::load_gui( const std::string& path )
     }
     catch( const Glib::FileError& ex )
     {
-        print_error( "FileError: " + ex.what() );
+        print_error( "FileError: ", ex.what() );
         return false;
     }
     catch( const Gtk::BuilderError& ex )
     {
-        print_error( "BuilderError: " + ex.what() );
+        print_error( "BuilderError: ", ex.what() );
         return false;
     }
 
