@@ -43,12 +43,11 @@ void handle_search_changed_tmp( GtkSearchEntry* entry, gpointer data )
 }
 
 PanelDiary::PanelDiary()
-: m_entry_count( 0 )
 {
     Gtk::Button* button_today;
     try
     {
-        Lifeograph::builder->get_widget( "G_elem_header", m_grid_elem_header );
+        Lifeograph::builder->get_widget( "G_elem_header", m_G_elem_header );
         Lifeograph::builder->get_widget( "Bx_new_elem", m_Bx_new_elem );
         Lifeograph::builder->get_widget( "B_today", button_today );
         Lifeograph::builder->get_widget( "MB_diary_add", m_MB_add );
@@ -69,24 +68,18 @@ PanelDiary::PanelDiary()
         Lifeograph::builder->get_widget( "MI_sort_by_change", m_MI_sort_by_change );
 
         Lifeograph::builder->get_widget( "Bx_search", m_Bx_search );
-        Lifeograph::builder->get_widget( "B_filter", m_B_filter );
+        Lifeograph::builder->get_widget( "Po_filter", m_Po_filter );
         Lifeograph::builder->get_widget( "B_filter_revert", m_B_filter_revert );
         Lifeograph::builder->get_widget( "E_search", m_E_search );
         Lifeograph::builder->get_widget_derived( "E_replace", m_E_replace );
         Lifeograph::builder->get_widget( "B_match_prev", m_B_match_prev );
         Lifeograph::builder->get_widget( "B_match_next", m_B_match_next );
-        Lifeograph::builder->get_widget( "G_replace", m_G_replace );
+        Lifeograph::builder->get_widget( "Po_replace", m_Po_replace );
         Lifeograph::builder->get_widget( "B_replace", m_B_replace );
         Lifeograph::builder->get_widget( "B_replace_all", m_B_replace_all );
 
         // THEMABLE ICONS
         Gtk::Image* img;
-        Lifeograph::builder->get_widget( "I_filter", img );
-        img->set( Lifeograph::icons->filter_16 );
-        Lifeograph::builder->get_widget( "I_filter_revert", img );
-        img->set( Lifeograph::icons->filter_revert_16 );
-
-
         Lifeograph::builder->get_widget( "I_add_entry", img );
         img->set( Lifeograph::icons->entry_16 );
         Lifeograph::builder->get_widget( "I_add_chapter", img );
@@ -109,10 +102,7 @@ PanelDiary::PanelDiary()
         Lifeograph::builder->get_widget( "calendar_main", m_calendar );
         Lifeograph::builder->get_widget_derived( "treeview_main", m_TV_entries );
 
-        m_PO_replace.add( *m_G_replace );
-        m_PO_replace.set_relative_to( *m_E_search );
-        m_PO_replace.set_modal( false );
-        m_PO_replace.set_opacity( 0.9 );
+        m_Po_replace->set_relative_to( *m_E_search );
     }
     catch( ... )
     {
@@ -157,8 +147,8 @@ PanelDiary::PanelDiary()
     m_MI_add_chapter->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_chapter ) );
 
-    m_B_filter->signal_clicked().connect(
-            sigc::mem_fun( Diary::d->m_filter_active, &DiaryElement::show ) );
+    m_Po_filter->signal_show().connect(
+            sigc::mem_fun( AppWindow::p->m_filter_view, &FilterView::update ) );
 
     m_B_filter_revert->signal_clicked().connect(
             sigc::mem_fun( this, &PanelDiary::revert_filter ) );
@@ -483,14 +473,6 @@ PanelDiary::handle_login()
     m_MI_logout_wo_saving->set_visible( ! Diary::d->is_read_only() );
     update_disable_auto_logout_MI();
 
-    static Gtk::Label* dummy_title = new Gtk::Label;
-    AppWindow::p->m_headerbar.pack_start( *m_Bx_new_elem );
-    AppWindow::p->m_headerbar.set_custom_title( *dummy_title );
-    AppWindow::p->m_headerbar.pack_start( *m_grid_elem_header );
-    AppWindow::p->m_headerbar.pack_end( *m_Bx_logout );
-    AppWindow::p->m_headerbar.pack_end( *m_B_tools );
-    AppWindow::p->m_headerbar.pack_end( *m_Bx_search );
-
     switch( Diary::d->get_sorting_criteria() )
     {
         default: // future-proofing
@@ -523,6 +505,11 @@ PanelDiary::handle_login()
     update_entry_list();
 
     m_MB_add->set_visible( ! Diary::d->is_read_only() );
+    m_Bx_new_elem->set_visible( true );
+    m_G_elem_header->set_visible( true );
+    m_Bx_logout->set_visible( true );
+    m_B_tools->set_visible( true );
+    m_Bx_search->set_visible( true );
 }
 
 void
@@ -530,14 +517,13 @@ PanelDiary::handle_logout()
 {
     Lifeograph::s_internaloperation++;
 
-    m_PO_replace.hide();
+    m_Po_replace->hide();
 
-    AppWindow::p->m_headerbar.remove( *m_Bx_new_elem );
-    gtk_header_bar_set_custom_title( AppWindow::p->m_headerbar.gobj(), NULL );
-    AppWindow::p->m_headerbar.remove( *m_grid_elem_header );
-    AppWindow::p->m_headerbar.remove( *m_Bx_logout );
-    AppWindow::p->m_headerbar.remove( *m_B_tools );
-    AppWindow::p->m_headerbar.remove( *m_Bx_search );
+    m_Bx_new_elem->set_visible( false );
+    m_G_elem_header->set_visible( false );
+    m_Bx_logout->set_visible( false );
+    m_B_tools->set_visible( false );
+    m_Bx_search->set_visible( false );
 
     m_TV_entries->clear();
 
@@ -552,8 +538,8 @@ PanelDiary::show( const DiaryElement* element )
 {
     if( element->get_type() >= DiaryElement::ET_DIARY ) // if a list element
         m_TV_entries->present_element( element );
-    //else - selected rows on the list no longer have any relation with the current view
-        //m_treeview_entries->get_selection()->unselect_all();
+    else // this may cause conflicts with multiple selections but very unlikely
+        m_TV_entries->get_selection()->unselect_all();
 
     if( element->get_type() > DiaryElement::ET_DIARY )
     {
@@ -934,10 +920,10 @@ PanelDiary::handle_search_string_changed()
     update_calendar();
 
     if( m_entry_count < 1 || filterstring.size() < 1 )
-        m_PO_replace.hide();
+        m_Po_replace->hide();
     else
     {
-        m_PO_replace.show();
+        m_Po_replace->show();
         bool show_replace( ! Diary::d->is_read_only() );
         m_E_replace->set_visible( show_replace );
         m_B_replace->set_visible( show_replace );
