@@ -29,10 +29,8 @@ using namespace LIFEO;
 
 
 PanelMain::PanelMain()
-:   m_bhist_index( 0 ), m_flag_index_locked( false ), m_flag_title_edit_in_progress( false ),
-    m_ptr2widget( NULL )
 {
-    Lifeograph::builder->get_widget( "vbox_panel_main", m_vbox_content );
+    Lifeograph::builder->get_widget( "St_views", m_St_content );
 
     Lifeograph::builder->get_widget( "Bx_header_title", m_Bx_elem_title );
     Lifeograph::builder->get_widget( "EB_header_title", m_eventbox_elem_title );
@@ -49,8 +47,6 @@ PanelMain::PanelMain()
     Lifeograph::builder->get_widget( "I_header_overlay", m_image_overlay );
     Lifeograph::builder->get_widget( "A_header_extra_tools", m_alignment_extra_tools );
 
-    Lifeograph::builder->get_widget( "B_filter", m_B_filter ); // mainly dealt by PanelDiary
-
     for( int i = 0; i < BROWSING_HISTORY_SIZE; i++ )
         m_browsing_history[ i ] = NULL;
 
@@ -81,10 +77,10 @@ PanelMain::PanelMain()
 }
 
 void
-PanelMain::show( ElementShowerProto* shower )
+PanelMain::show( ElementViewProto* shower )
 {
     PRINT_DEBUG( "====================" );
-    PRINT_DEBUG2( "DEID: ", shower->get_element()->get_id() );
+    PRINT_DEBUG( "DEID: ", shower->get_element()->get_id() );
     PRINT_DEBUG( "====================" );
 
     if( m_flag_title_edit_in_progress )
@@ -115,28 +111,18 @@ PanelMain::show( ElementShowerProto* shower )
     update_overlay_icon();
 
     // TOOLBAR
-    if( Gtk::Widget* widget = shower->get_popover() )
-    {
-        m_popover_elem.remove();
-        m_popover_elem.add( *widget );
-        m_button_elem->set_popover( m_popover_elem );
-    }
+    if( nullptr != ( m_Po_elem = shower->get_popover() ) )
+        m_button_elem->set_popover( *m_Po_elem );
     else
         m_button_elem->unset_popover();
 
     set_extra_tools( shower->get_extra_tools() );
 
-    m_B_filter->set_sensitive( shower->get_element()->get_type() != DiaryElement::ET_FILTER );
-
     // CONTENT
     if( m_ptr2widget != shower->get_widget() )
     {
-        if( m_ptr2widget )
-        {
-            m_vbox_content->remove( *m_ptr2widget );
-        }
-        m_vbox_content->pack_start( *shower->get_widget() );
         m_ptr2widget = shower->get_widget();
+        m_St_content->set_visible_child( *m_ptr2widget );
     }
 
     m_flag_title_editable = ( m_cur_shower->is_title_editable() && ! Diary::d->is_read_only() );
@@ -149,13 +135,13 @@ PanelMain::show( ElementShowerProto* shower )
 void
 PanelMain::handle_login()
 {
-    AppWindow::p->m_headerbar.pack_start( *m_button_back );
+    m_button_back->set_visible( true );
 }
 
 void
 PanelMain::handle_logout()
 {
-    AppWindow::p->m_headerbar.remove( *m_button_back );
+    m_button_back->set_visible( false );
 
     cancel_title_edit(); // checks if title edit is in progress
 
@@ -181,10 +167,12 @@ PanelMain::go_back()
     {
         if( m_browsing_history[ i ] != NULL )
         {
+            m_St_content->set_transition_type( Gtk::STACK_TRANSITION_TYPE_SLIDE_RIGHT );
             m_flag_index_locked = true;
             m_browsing_history[ i ]->show();
             m_bhist_index = i;
             m_flag_index_locked = false;
+            m_St_content->set_transition_type( Gtk::STACK_TRANSITION_TYPE_SLIDE_LEFT );
             return;
         }
     }
