@@ -34,20 +34,19 @@ using namespace LIFEO;
 
 
 EntryView::EntryView()
-:   m_tag_operation_cur( TO_NONE ), m_entry_sync( NULL ), m_flag_entrychanged( false )
 {
     Entry::shower = this;
 
     Gtk::Button* button_print;
 
-    Gtk::Button* button_hide( NULL );
-    Gtk::Button* button_hide_before( NULL );
-    Gtk::Button* button_hide_after( NULL );
+    Gtk::Button* button_hide( nullptr );
+    Gtk::Button* button_hide_before( nullptr );
+    Gtk::Button* button_hide_after( nullptr );
 
     try
     {
-        Lifeograph::builder->get_widget( "Bx_entry", m_vbox );
-        Lifeograph::builder->get_widget( "G_entry_popover", m_grid_popover );
+        Lifeograph::builder->get_widget( "Bx_entry", m_box );
+        Lifeograph::builder->get_widget( "Po_entry", m_Po_elem );
         Lifeograph::builder->get_widget( "RB_entry_not_todo", m_button_not_todo );
         Lifeograph::builder->get_widget( "RB_entry_todo", m_button_todo );
         Lifeograph::builder->get_widget( "RB_entry_progressed", m_button_progressed );
@@ -84,12 +83,12 @@ EntryView::EntryView()
         Lifeograph::builder->get_widget( "TB_entry_comments", m_TB_comments );
         Lifeograph::builder->get_widget_derived( "TV_entry", m_textview );
 
-        Lifeograph::builder->get_widget( "Bx_entry_tag_edit", m_box_tag_edit );
+        Lifeograph::builder->get_widget( "Bx_entry_tag_edit", m_Bx_tag_edit );
         Lifeograph::builder->get_widget( "Bx_entry_tag_linked", m_Bx_tag_linked );
-        Lifeograph::builder->get_widget_derived( "E_tag_filter", m_tag_widget );
+        Lifeograph::builder->get_widget_derived( "E_tag_filter", m_W_tag_edit );
         Lifeograph::builder->get_widget( "B_entry_tag", m_button_tag_operation );
         Lifeograph::builder->get_widget( "B_entry_tag_theme", m_button_set_theme );
-        Lifeograph::builder->get_widget_derived( "DA_entry_tags", m_widgettaglist );
+        Lifeograph::builder->get_widget_derived( "DA_entry_tags", m_W_tag_list );
 
         // THEMABLE ICONS
         Gtk::Image* img;
@@ -130,7 +129,7 @@ EntryView::EntryView()
     m_textview->drag_dest_get_target_list()->add( Lifeograph::p->drag_targets_entry );
 
     // TAGS WIDGET
-    m_widgettaglist->drag_dest_set( Lifeograph::p->drag_targets_tag );
+    m_W_tag_list->drag_dest_set( Lifeograph::p->drag_targets_tag );
 
     // SIGNALS
     m_textview->m_buffer->signal_changed().connect(
@@ -179,22 +178,24 @@ EntryView::EntryView()
     m_textview->signal_drag_data_received().connect(
             sigc::mem_fun( this, &EntryView::handle_drag_data_received ) );
 
-    m_tag_widget->signal_changed().connect(
-            sigc::mem_fun( this, &EntryView::handle_entry_tag_changed ) );
+    m_W_tag_edit->signal_updated().connect(
+            sigc::mem_fun( this, &EntryView::handle_W_tag_updated ) );
     m_textview->signal_focus_in_event().connect_notify(
             sigc::mem_fun( this, &EntryView::handle_tag_entry_focus_out ) );
-    m_tag_widget->signal_activate().connect(
+    m_W_tag_edit->signal_activate().connect(
             sigc::mem_fun( this, &EntryView::handle_button_tag_clicked ) );
     m_button_tag_operation->signal_clicked().connect(
             sigc::mem_fun( this, &EntryView::handle_button_tag_clicked ) );
     m_button_set_theme->signal_clicked().connect(
             sigc::mem_fun( this, &EntryView::handle_set_theme ) );
-    m_widgettaglist->signal_drag_data_received().connect(
+    m_W_tag_list->signal_drag_data_received().connect(
             sigc::mem_fun( this, &EntryView::handle_drag_data_received ) );
-    m_widgettaglist->signal_add_tag().connect(
+    m_W_tag_list->signal_add_tag().connect(
             sigc::mem_fun( this, &EntryView::focus_tag_entry ) );
-    m_widgettaglist->signal_tag_selected().connect(
+    m_W_tag_list->signal_tag_selected().connect(
             sigc::mem_fun( this, &EntryView::edit_tag_in_entry ) );
+    m_W_tag_list->signal_tag_double_clicked().connect(
+            sigc::mem_fun( this, &EntryView::show_tag ) );
 
     // EDITOR ACTIONS
     Lifeograph::create_action(
@@ -255,6 +256,10 @@ EntryView::EntryView()
             true, m_action_move_line_down, "MoveLineDown", "", "",
             Gtk::AccelKey( GDK_KEY_Down, Gdk::MOD1_MASK ),
             sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::move_line_down ) );
+    Lifeograph::create_action(
+            true, m_action_delete_paragraph, "DeleteParagraph", "", "",
+            Gtk::AccelKey( GDK_KEY_x, Gdk::MOD1_MASK ),
+            sigc::mem_fun( m_textview->m_buffer, &TextbufferDiary::delete_paragraph ) );
 
     Lifeograph::create_action(
             true, m_action_time_stamp, "TimeStamp", "", "",
@@ -300,7 +305,7 @@ EntryView::handle_login()
     // READ ONLY
     bool editable( ! Diary::d->is_read_only() );
     m_textview->set_editable( editable );
-    m_widgettaglist->set_editable( editable );
+    m_W_tag_list->set_editable( editable );
     m_button_not_todo->set_visible( editable );
     m_button_todo->set_visible( editable );
     m_button_progressed->set_visible( editable );
@@ -357,7 +362,7 @@ EntryView::handle_drag_data_received(
             Tag* tag = dynamic_cast< Tag* >( Lifeograph::s_elem_dragged );
             if( m_ptr2elem->add_tag( tag ) ) // if does not already have the tag
             {
-                m_widgettaglist->update();
+                m_W_tag_list->update();
                 if( tag->get_has_own_theme() )
                     update_theme();
                 // note: even if tag has its own theme it is not applied if entry has already
@@ -368,7 +373,7 @@ EntryView::handle_drag_data_received(
         case DiaryElement::ET_UNTAGGED:
             if( m_ptr2elem->clear_tags() )
             {
-                m_widgettaglist->update();
+                m_W_tag_list->update();
                 update_theme();
             }
             break;
@@ -425,7 +430,7 @@ EntryView::print()
     catch( const Gtk::PrintError &ex )
     {
         // See documentation for exact Gtk::PrintError error codes:
-        print_error( "An error occurred while trying to run a print operation:" +
+        print_error( "An error occurred while trying to run a print operation:",
                 ex.what() );
     }
 }
@@ -468,16 +473,25 @@ EntryView::trash_entry()
 {
     AppWindow::p->panel_main->hide_popover();
 
-    Diary::d->show();
-
-    AppWindow::p->panel_main->remove_element_from_history( m_ptr2elem );
     m_ptr2elem->set_trashed( true );
-    if( Diary::d->get_startup_elem() == m_ptr2elem )
+
+    if( !( Diary::d->get_filter()->get_status() & ES::SHOW_TRASHED ) )
     {
-        Diary::d->set_startup_elem( Diary::d->get_id() );
-        AppWindow::p->m_diary_view->update_startup_elem();
+        Diary::d->show();
+        AppWindow::p->panel_main->remove_element_from_history( m_ptr2elem );
+        if( Diary::d->get_startup_elem() == m_ptr2elem )
+        {
+            Diary::d->set_startup_elem( Diary::d->get_id() );
+            AppWindow::p->m_diary_view->update_startup_elem();
+        }
+        Diary::d->get_filter()->set_status_outstanding();
+    }
+    else
+    {
+        m_button_trash->set_visible( false );
+        m_button_restore->set_visible( true );
+        m_button_dismiss->set_visible( true );
     }
-    Diary::d->get_filter()->set_status_outstanding();
 
     Lifeograph::s_internaloperation++;
 
@@ -492,9 +506,12 @@ EntryView::restore_entry()
 {
     AppWindow::p->panel_main->hide_popover();
 
-    Diary::d->show();
-
     m_ptr2elem->set_trashed( false );
+
+    m_button_trash->set_visible( true );
+    m_button_restore->set_visible( false );
+    m_button_dismiss->set_visible( false );
+
     Diary::d->get_filter()->set_status_outstanding();
 
     Lifeograph::s_internaloperation++;
@@ -513,15 +530,15 @@ EntryView::dismiss_entry()
     if( ! AppWindow::p->confirm_dismiss_element( m_ptr2elem ) )
         return;
 
-    // first make sure that entry to be deleted is completely out of business...
-    // ...else dark forces may take action and cause SEGFAULT:
-    Diary::d->show();
+    // first we need to make sure that the tag list widget will not try to update
+    // or a segfault will ensue:
+    m_W_tag_list->set_entry( nullptr );
+
+    Lifeograph::s_internaloperation++;
 
     AppWindow::p->panel_main->remove_element_from_history( m_ptr2elem );
     Diary::d->dismiss_entry( m_ptr2elem );
 
-    Lifeograph::s_internaloperation++;
-
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 
@@ -561,45 +578,37 @@ EntryView::apply_title( const Glib::ustring& str )
 }
 
 void
-EntryView::handle_entry_tag_changed()
+EntryView::handle_W_tag_updated( WidgetTagEdit::TagOperation to, Tag* tag )
 {
-    Glib::ustring filter = m_tag_widget->get_text();
-
     m_button_set_theme->hide();
+    m_Bx_tag_linked->get_style_context()->add_class( "linked" );
+    m_button_tag_operation->show();
 
-    if( filter.empty() )
+    switch( to )
     {
-        m_Bx_tag_linked->get_style_context()->remove_class( "linked" );
-        m_button_tag_operation->hide();
-        m_tag_operation_cur = TO_NONE;
-
-    }
-    else
-    {
-        m_Bx_tag_linked->get_style_context()->add_class( "linked" );
-        m_button_tag_operation->show();
-        Tag* tag = Diary::d->get_tags()->get_tag( filter );
-        if( tag == NULL )
-        {
+        case WidgetTagEdit::TO_INVALID:
+        case WidgetTagEdit::TO_NONE:
+            m_Bx_tag_linked->get_style_context()->remove_class( "linked" );
+            m_button_tag_operation->hide();
+            break;
+        case WidgetTagEdit::TO_CREATE_BOOLEAN:
+        case WidgetTagEdit::TO_CREATE_CUMULATIVE:
             m_button_tag_operation->set_label( _( "Create Tag" ) );
-            m_tag_operation_cur = TO_CREATE_AND_ADD;
-        }
-        else
-        {
-            if( m_ptr2elem->get_tags().checkfor_member( tag ) )
-            {
-                m_button_tag_operation->set_label( _( "Remove Tag" ) );
-                m_tag_operation_cur = TO_REMOVE;
+            break;
+        case WidgetTagEdit::TO_REMOVE:
+            m_button_tag_operation->set_label( _( "Remove Tag" ) );
 
-                if( tag->get_has_own_theme() && m_ptr2elem->get_theme_tag() != tag )
-                    m_button_set_theme->show();
-            }
-            else
-            {
-                m_button_tag_operation->set_label( _( "Add Tag" ) );
-                m_tag_operation_cur = TO_ADD;
-            }
-        }
+            if( tag->get_has_own_theme() && m_ptr2elem->get_theme_tag() != tag )
+                m_button_set_theme->show();
+            break;
+        case WidgetTagEdit::TO_ADD:
+            m_button_tag_operation->set_label( _( "Add Tag" ) );
+            break;
+        case WidgetTagEdit::TO_CHANGE_VALUE:
+            m_button_tag_operation->set_label( _( "Change Value" ) );
+            break;
+        default:
+            break;
     }
 }
 
@@ -607,41 +616,53 @@ void
 EntryView::handle_button_tag_clicked()
 {
     Tag* tag;
-    Glib::ustring filter = m_tag_widget->get_text();
+    NameAndValue&& nav{ m_W_tag_edit->get_nav() };
 
-    switch( m_tag_operation_cur )
+    switch( m_W_tag_edit->get_status() )
     {
-        case TO_NONE:
+        case WidgetTagEdit::TO_NONE:
+        case WidgetTagEdit::TO_INVALID:
             return; // don't even clear
-        case TO_REMOVE:
-            tag = Diary::d->get_tags()->get_tag( filter );
+        case WidgetTagEdit::TO_REMOVE:
+            tag = Diary::d->get_tags()->get_tag( nav.name );
             m_ptr2elem->remove_tag( tag );
             break;
-        case TO_CREATE_AND_ADD:
-            tag = Diary::d->create_tag( filter );
-            m_ptr2elem->add_tag( tag );
+        case WidgetTagEdit::TO_CREATE_BOOLEAN:
+        case WidgetTagEdit::TO_CREATE_CUMULATIVE:
+            if( m_W_tag_edit->get_status() == WidgetTagEdit::TO_CREATE_CUMULATIVE )
+                tag = Diary::d->create_tag( nav.name, nullptr,
+                                            ChartPoints::MONTHLY|ChartPoints::CUMULATIVE );
+            else
+                tag = Diary::d->create_tag( nav.name, nullptr );
+
+            m_ptr2elem->add_tag( tag, nav.value );
             AppWindow::p->panel_extra->populate();
-            m_tag_widget->populate();
+            m_W_tag_edit->populate();
             break;
-        case TO_ADD:
-            tag = Diary::d->get_tags()->get_tag( filter );
-            m_ptr2elem->add_tag( tag );
+        case WidgetTagEdit::TO_ADD:
+            tag = Diary::d->get_tags()->get_tag( nav.name );
+            m_ptr2elem->add_tag( tag, nav.value );
+            break;
+        case WidgetTagEdit::TO_CHANGE_VALUE:
+            tag = Diary::d->get_tags()->get_tag( nav.name );
+            m_ptr2elem->remove_tag( tag );
+            m_ptr2elem->add_tag( tag, nav.value );
             break;
     }
 
-
     if( tag->get_has_own_theme() )
         update_theme();
-    m_widgettaglist->update();
-    m_tag_widget->set_text( "" );
+    m_W_tag_list->update();
+    m_W_tag_edit->clear();
 }
 
 void
 EntryView::handle_set_theme()
 {
-    if( m_tag_operation_cur == TO_REMOVE ) // only tags in entry can be set as the theme
+    // only tags in entry can be set as the theme:
+    if( m_W_tag_edit->get_status() == WidgetTagEdit::TO_REMOVE )
     {
-        Tag* tag = Diary::d->get_tags()->get_tag( m_tag_widget->get_text() );
+        Tag* tag = Diary::d->get_tags()->get_tag( m_W_tag_edit->get_nav().name );
 
         if( tag->get_has_own_theme() )
         {
@@ -657,16 +678,16 @@ EntryView::focus_tag_entry()
 {
     if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
     {
-        m_box_tag_edit->show();
-        m_tag_widget->set_text( "" );
-        m_tag_widget->grab_focus();
+        m_Bx_tag_edit->show();
+        m_W_tag_edit->clear();
+        m_W_tag_edit->grab_focus();
     }
 }
 
 void
 EntryView::handle_tag_entry_focus_out( GdkEventFocus* )
 {
-    m_box_tag_edit->set_visible( false );
+    m_Bx_tag_edit->set_visible( false );
 }
 
 void
@@ -675,12 +696,18 @@ EntryView::edit_tag_in_entry( const Tag* tag )
     if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY &&
         !Diary::d->is_read_only() )
     {
-        m_box_tag_edit->show();
-        m_tag_widget->set_text( tag->get_name() );
-        m_tag_widget->grab_focus();
+        m_Bx_tag_edit->show();
+        m_W_tag_edit->set_text( tag );
+        m_W_tag_edit->grab_focus();
     }
 }
 
+void
+EntryView::show_tag( const Tag* tag )
+{
+    const_cast< Tag* >( tag )->show();
+}
+
 void
 EntryView::show( Entry& entry )
 {
@@ -690,7 +717,7 @@ EntryView::show( Entry& entry )
 
     m_ptr2elem = &entry; // must be first thing
 
-    m_box_tag_edit->set_visible( false );
+    m_Bx_tag_edit->set_visible( false );
 
     AppWindow::p->panel_main->show( this );
     m_label_created->set_text( m_ptr2elem->get_date_created_str() );
@@ -736,8 +763,9 @@ EntryView::show( Entry& entry )
 
     Lifeograph::s_internaloperation--;
 
-    m_widgettaglist->set_entry( &entry );
-    m_tag_widget->populate();
+    m_W_tag_list->set_entry( &entry );
+    m_W_tag_edit->set_entry( &entry );
+    m_W_tag_edit->populate();
 
     m_entry_sync = m_ptr2elem;
 
@@ -748,7 +776,9 @@ void
 EntryView::prepare_for_hiding( Entry& entry )
 {
     sync();
-    m_tag_widget->set_text( "" );
+    m_W_tag_edit->clear();
+    m_W_tag_list->set_entry( nullptr );
+    PRINT_DEBUG( "EntryView::prepare_for_hiding()" );
 }
 
 void
