@@ -128,9 +128,8 @@ LinkEntry::go()
             delete menu_link;
         menu_link = new Gtk::Menu;
 
-        for( EntryVectorIter iter = entries->begin(); iter != entries->end(); ++iter )
+        for( Entry* entry : *entries )
         {
-            Entry* entry = ( *iter );
             Gtk::MenuItem* mitem = Gtk::manage( new Gtk::MenuItem( entry->get_name() ) );
             mitem->signal_activate().connect( sigc::mem_fun( entry, &Entry::show ) );
             menu_link->append( *mitem );
@@ -185,15 +184,12 @@ LinkCheck::go()
     PRINT_DEBUG( "LinkCheck::go()" );
     //m_state_index = ( m_state_index + 1 ) % 4; // the old way. may be added back as an alternative
 
-    static Gtk::Grid* G_content = NULL;
-    static Gtk::Popover* PO_check = NULL;
+    static Gtk::Popover* Po_check{ nullptr };
     static Gtk::RadioButton* RB_status[ 4 ];
 
-    if( !G_content )
+    if( !Po_check )
     {
-        Lifeograph::builder->get_widget( "G_checklist_popover", G_content );
-        PO_check = Gtk::manage( new Gtk::Popover );
-        PO_check->add( *G_content );
+        Lifeograph::builder->get_widget( "Po_entry_checklist", Po_check );
         Lifeograph::builder->get_widget( "RB_checklist_todo", RB_status[ 0 ] );
         RB_status[ 0 ]->signal_clicked().connect(
                 sigc::bind( sigc::ptr_fun( &LinkCheck::set_check ), 0 ) );
@@ -227,7 +223,7 @@ LinkCheck::go()
     Gtk::TextIter iter = m_mark_start->get_iter();
     iter++;
 
-    PO_check->set_relative_to( *AppWindow::p->m_entry_view->get_textview() );
+    Po_check->set_relative_to( *AppWindow::p->m_entry_view->get_textview() );
     AppWindow::p->m_entry_view->get_textview()->get_iter_location( iter, rect );
     AppWindow::p->m_entry_view->get_textview()->buffer_to_window_coords(
             Gtk::TEXT_WINDOW_TEXT, rect.get_x(), rect.get_y(), win_x, win_y );
@@ -236,10 +232,9 @@ LinkCheck::go()
 
     s_pos_mark = m_mark_start->get_iter().get_offset() + 1;
 
-    PO_check->set_pointing_to( rect );
-    PO_check->set_position( Gtk::POS_BOTTOM );
-    PO_check->set_modal( true );
-    PO_check->show();
+    Po_check->set_pointing_to( rect );
+    Po_check->set_position( Gtk::POS_BOTTOM );
+    Po_check->show();
 }
 
 void
@@ -284,11 +279,7 @@ InlineImage::~InlineImage()
 
 // TEXTBUFFERDIARY =================================================================================
 TextbufferDiary::TextbufferDiary()
-:   Gtk::TextBuffer(),
-//    parser_open_tag_is_link( false ),
-    m_flag_settextoperation( false ), m_flag_ongoing_operation( 0 ), m_flag_parsing( false ),
-    m_flag_updating_search_text( false ),
-    m_ptr2textview( NULL ), m_max_thumbnail_width( 0 ), m_enchant_dict( NULL )
+:   Gtk::TextBuffer()
 {
     LinkUri::m_ptr2buffer = this;
     UndoEdit::m_ptr2buffer = this;
@@ -423,7 +414,8 @@ TextbufferDiary::set_search_str( const Glib::ustring& str )
     m_flag_ongoing_operation++;
     place_cursor( begin() );
     m_flag_ongoing_operation--;
-    reparse();
+    if( m_ptr2entry )
+        reparse();
     m_flag_updating_search_text = false;
 }
 
@@ -840,9 +832,9 @@ TextbufferDiary::apply_indent()
     tag_indent->property_left_margin() = tab_width; // FIXME: indents more than expected
     tag_indent->property_indent() = -tab_width;
 
-    PRINT_DEBUG2( "tab width= " , tab_width );
-    PRINT_DEBUG2( "pos_current= " , pos_current );
-    PRINT_DEBUG2( "m_pos_start= " , m_pos_start );
+    PRINT_DEBUG( "tab width= " , tab_width );
+    PRINT_DEBUG( "pos_current= " , pos_current );
+    PRINT_DEBUG( "m_pos_start= " , m_pos_start );
 
     get_tag_table()->add( tag_indent );
 
@@ -923,7 +915,10 @@ TextbufferDiary::on_insert( const Gtk::TextIter& iterator,
         UndoManager::m->add_action( undo_insert );
     }
 
-    Gtk::TextBuffer::on_insert( iterator, text2, bytes );
+    if( text == "-" && handle_minus() )
+        PRINT_DEBUG( "em dash inserted" );
+    else
+        Gtk::TextBuffer::on_insert( iterator, text2, bytes );
 
     if( m_flag_ongoing_operation || m_flag_parsing )
         return;
@@ -941,11 +936,11 @@ TextbufferDiary::on_insert( const Gtk::TextIter& iterator,
         Gtk::TextIter iter_end( get_iter_at_offset( offset_itr + text2.length() ) );
         calculate_para_bounds( iter_begin, iter_end );
 
-        PRINT_DEBUG2( "cursor: ", get_insert()->get_iter().get_offset() );
-        PRINT_DEBUG5( "    para: (", m_parser_pos_cur_para_begin,
+        PRINT_DEBUG( "cursor: ", get_insert()->get_iter().get_offset() );
+        PRINT_DEBUG( "    para: (", m_parser_pos_cur_para_begin,
                              ", ", m_parser_pos_cur_para_end, ")" );
 
-        PRINT_DEBUG3( "parsed slice: \"\"\"", get_slice( iter_begin, iter_end ), "\"\"\"" );
+        PRINT_DEBUG( "parsed slice: \"\"\"", get_slice( iter_begin, iter_end ), "\"\"\"" );
 
         // TODO: update cur paragraph
 
@@ -1009,6 +1004,31 @@ TextbufferDiary::handle_space()
     }
 }
 
+bool
+TextbufferDiary::handle_minus() // replaces 3 minus signs with an em dash
+{
+    Gtk::TextIter iter = get_iter_at_mark( get_insert() );
+    for( int count{ 0 }; iter.backward_char(); )
+    {
+        switch( iter.get_char() )
+        {
+            case '-':
+                if( ++count == 2 )
+                {
+                    m_flag_ongoing_operation++;
+                    iter = erase( iter, get_iter_at_mark( get_insert() ) );
+                    m_flag_ongoing_operation--;
+                    insert( iter, "—" );
+                    return true;
+                }
+                break;
+            default:
+                return false;
+        }
+    }
+    return false;
+}
+
 bool
 TextbufferDiary::handle_new_line()
 {
@@ -1240,15 +1260,15 @@ TextbufferDiary::on_mark_set( const TextBuffer::iterator& iter,
         ! Diary::d->is_read_only() && ! get_has_selection() && mark == get_insert() )
     {
 #if LIFEOGRAPH_DEBUG_BUILD
-        PRINT_DEBUG2( "TextbufferDiary::on_mark_set() -- cursor: ",
-                      get_insert()->get_iter().get_offset() );
-        PRINT_DEBUG5( "    para: (", m_parser_pos_cur_para_begin,
-                      ", ", m_parser_pos_cur_para_end, ")" );
+        PRINT_DEBUG( "TextbufferDiary::on_mark_set() -- cursor: ",
+                     get_insert()->get_iter().get_offset() );
+        PRINT_DEBUG( "    para: (", m_parser_pos_cur_para_begin,
+                     ", ", m_parser_pos_cur_para_end, ")" );
 
         for( ListImages::iterator it = m_list_images.begin(); it != m_list_images.end(); it++ )
         {
             InlineImage* img( *it );
-            PRINT_DEBUG2( "img: ", img->m_offset );
+            PRINT_DEBUG( "img: ", img->m_offset );
         }
 #endif
 
@@ -1390,13 +1410,10 @@ TextbufferDiary::get_link( int offset ) const
 Link*
 TextbufferDiary::get_link( const Gtk::TextIter& iter ) const
 {
-    for( ListLinks::const_iterator link = m_list_links.begin();
-          link != m_list_links.end();
-          ++link )
+    for( Link* link : m_list_links )
     {
-        if( iter.in_range( ( *link )->m_mark_start->get_iter(),
-                           ( *link )->m_mark_end->get_iter() ) )
-            return( *link );
+        if( iter.in_range( link->m_mark_start->get_iter(), link->m_mark_end->get_iter() ) )
+            return( link );
     }
     return NULL;
 }
@@ -1421,19 +1438,16 @@ TextbufferDiary::clear_links( int start, int end )
 void
 TextbufferDiary::clear_links()
 {
-    for( ListLinks::iterator iter = m_list_links.begin();
-         iter != m_list_links.end();
-         ++iter )
-    {
-        delete( *iter );
-    }
+    for( Link* link : m_list_links )
+        delete( link );
+
     m_list_links.clear();
 }
 
 void
 TextbufferDiary::clear_images( int start, int& end )
 {
-    PRINT_DEBUG5( "TextbufferDiary::clear_images( ", start, ", ", end, " )" );
+    PRINT_DEBUG( "TextbufferDiary::clear_images( ", start, ", ", end, " )" );
 
     //assert( m_flag_parsing );   // this function should only be called during parsing
 
@@ -1454,12 +1468,8 @@ TextbufferDiary::clear_images( int start, int& end )
             erase( titer_begin, ++titer_end );
 
             // UPDATE OFFSETS
-            for( ListImages::iterator iter2 = m_list_images.begin();
-                 iter2 != m_list_images.end();
-                 ++iter2 )
+            for( InlineImage* img2 : m_list_images )
             {
-                InlineImage* img2( *iter2 );
-
                 if( img->m_offset < img2->m_offset )
                     img2->m_offset--;
             }
@@ -1477,11 +1487,9 @@ TextbufferDiary::clear_images( int start, int& end )
 void
 TextbufferDiary::clear_images() // note that this version does not alter the buffer
 {
-    for( ListImages::iterator iter = m_list_images.begin();
-         iter != m_list_images.end();
-         ++iter )
+    for( InlineImage* img : m_list_images )
     {
-        delete( *iter );
+        delete( img );
     }
     m_list_images.clear();
 }
@@ -1510,13 +1518,11 @@ TextbufferDiary::update_thumbnail_width( int width )
 void
 TextbufferDiary::update_offsets( int pos, int delta )
 {
-    PRINT_DEBUG5( "TextbufferDiary::update_image_offsets( ", pos, ", ", delta, " )" );
-    PRINT_DEBUG5( "para - before: (", m_parser_pos_cur_para_begin, ", ", m_parser_pos_cur_para_end, ")" );
+    PRINT_DEBUG( "TextbufferDiary::update_image_offsets( ", pos, ", ", delta, " )" );
+    PRINT_DEBUG( "para - before: (", m_parser_pos_cur_para_begin, ", ", m_parser_pos_cur_para_end, ")" );
 
-    for( ListImages::iterator iter = m_list_images.begin(); iter != m_list_images.end(); ++iter )
+    for( InlineImage* img : m_list_images )
     {
-        InlineImage* img( *iter );
-
         if( pos < img->m_offset )
             img->m_offset += delta;
     }
@@ -2102,6 +2108,21 @@ TextbufferDiary::move_line_down()
     }
 }
 
+void
+TextbufferDiary::delete_paragraph()
+{
+    if( ! m_ptr2textview->has_focus() )
+        return;
+
+    Gtk::TextIter iter_begin;
+    Gtk::TextIter iter_end;
+
+    calculate_multi_para_bounds( iter_begin, iter_end );
+    iter_end++;
+
+    erase( iter_begin, iter_end );
+}
+
 void
 TextbufferDiary::insert_link( DiaryElement* element )
 {
@@ -2156,6 +2177,19 @@ TextbufferDiary::set_richtext( Entry* entry )
     m_flag_settextoperation = false;
 }
 
+Glib::ustring
+TextbufferDiary::get_selected_text() const
+{
+    if( get_has_selection() )
+    {
+        Gtk::TextIter iter_start, iter_end;
+        get_selection_bounds( iter_start, iter_end );
+        return get_text( iter_start, iter_end );
+    }
+    else
+        return "";
+}
+
 inline Gdk::RGBA
 midcontrast( const Theme* theme, const Gdk::RGBA& color_target )
 {
@@ -2170,12 +2204,33 @@ midcontrast( const Theme* theme, const Gdk::RGBA& color_target )
 void
 TextbufferDiary::set_theme( const Theme* theme )
 {
-    m_ptr2textview->override_font( theme->font );
-    m_ptr2textview->override_background_color( theme->color_base, Gtk::STATE_FLAG_NORMAL );
-    m_ptr2textview->override_color( theme->color_text, Gtk::STATE_FLAG_NORMAL );
+    //TODO: check in Gtk+3.12
+    static Glib::RefPtr< Gtk::CssProvider > css_provider;
 
-    m_ptr2textview->override_background_color( theme->color_heading, Gtk::STATE_FLAG_SELECTED );
-    m_ptr2textview->override_color( theme->color_base, Gtk::STATE_FLAG_SELECTED );
+    int size{ theme->font.get_size() };
+    if( ! theme->font.get_size_is_absolute() )
+        size /= PANGO_SCALE;
+
+    PRINT_DEBUG( "theme size=", theme->font.get_size(),
+                 "  size=", size,
+                 "  PANGO_SCLAE=", PANGO_SCALE );
+
+    const Glib::ustring data{
+            STR::compose(
+                "textview { font-family: ", theme->font.get_family(), "; "
+                    "font-size: ", size, "pt }\n"
+                "text { color: ", theme->color_text.to_string(), "; "
+                    "background-color: ", theme->color_base.to_string(), " }\n"
+                "text:selected, text selection { color: ", theme->color_base.to_string(), "; "
+                    "background: ", theme->color_heading.to_string(), " }"
+                ) };
+
+    if( css_provider )
+        m_ptr2textview->get_style_context()->remove_provider( css_provider );
+    css_provider = Gtk::CssProvider::create();
+    if( css_provider->load_from_data( data ) )
+        m_ptr2textview->get_style_context()->add_provider(
+                css_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION );
 
     m_tag_heading->property_foreground_rgba() = theme->color_heading;
     m_tag_subheading->property_foreground_rgba() = theme->color_subheading;
@@ -2249,7 +2304,7 @@ TextbufferDiary::set_language( std::string lang )
 
     if( !m_enchant_dict )
     {
-        print_error( "Enchant error for language: " + lang );
+        print_error( "Enchant error for language: ", lang );
         m_flag_handle_word = false;
         return "";
     }
@@ -2466,8 +2521,7 @@ TextviewDiary::TextviewDiary( BaseObjectType* cobject, const Glib::RefPtr< Gtk::
 :   Gtk::TextView( cobject ),
     m_cursor_hand( Gdk::Cursor::create( Gdk::HAND2 ) ),
     m_cursor_xterm( Gdk::Cursor::create( Gdk::XTERM ) ),
-    m_ptr2cursor_last( &m_cursor_xterm ), m_link_hovered( NULL ),
-    m_flag_size_allocated( false ), m_flag_set_text_queued( false )
+    m_ptr2cursor_last( &m_cursor_xterm )
 {
     m_buffer = new TextbufferDiary;
     set_buffer( static_cast< Glib::RefPtr< TextbufferDiary > >( m_buffer ) );
@@ -2735,7 +2789,7 @@ TextviewDiary::handle_query_tooltip( int x, int y, bool keyboard_mode,
         }
 
         tooltip->set_text( tooltip_text );
-        //tooltip->set_icon_from_stock( Gtk::Stock::INFO, Gtk::ICON_SIZE_MENU );
+        //tooltip->set_icon_from_icon_name( "dialog-information", Gtk::ICON_SIZE_MENU );
     }
     else
         return false;
