@@ -307,6 +307,7 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         Link*                       get_link( const Gtk::TextIter& ) const;
 
         void                        set_richtext( Entry* );
+        Glib::ustring               get_selected_text() const;
 
         void                        set_search_str( const Glib::ustring& );
         bool                        select_searchstr_previous();
@@ -334,6 +335,7 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         void                        remove_empty_line_above();
         void                        move_line_up();
         void                        move_line_down();
+        void                        delete_paragraph();
         void                        insert_link( DiaryElement* );
         void                        insert_time_stamp();
 
@@ -361,6 +363,7 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
                                                  const Glib::RefPtr< TextBuffer::Mark >& );
 
         void                        handle_space();
+        bool                        handle_minus();
         bool                        handle_new_line();
         bool                        increment_numbered_line( Gtk::TextIter&, int );
 
@@ -411,8 +414,8 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         void                        replace_misspelled_word( const Glib::ustring& );
         void                        add_word_to_dictionary( const Glib::ustring& );
 
-        Wstring::size_type          m_parser_pos_cur_para_begin;
-        Wstring::size_type          m_parser_pos_cur_para_end;
+        Wstring::size_type          m_parser_pos_cur_para_begin{ 0 };
+        Wstring::size_type          m_parser_pos_cur_para_end{ 0 };
 
         static PredicateNL          s_predicate_nl;
 
@@ -455,23 +458,23 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         VecTags                     m_tags;
 
         // OTHER VARIABLES
-        bool                        m_flag_settextoperation;
-        int                         m_flag_ongoing_operation;   // Incremental to allow nesting
-        bool                        m_flag_parsing;
-        bool                        m_flag_updating_search_text;
-        Entry*                      m_ptr2entry;
-        Gtk::TextView*              m_ptr2textview;
+        bool                        m_flag_settextoperation{ false };
+        int                         m_flag_ongoing_operation{ 0 };   // Incremental to allow nesting
+        bool                        m_flag_parsing{ false };
+        bool                        m_flag_updating_search_text{ false };
+        Entry*                      m_ptr2entry{ nullptr };
+        Gtk::TextView*              m_ptr2textview{ nullptr };
 
         typedef std::list< Link* >  ListLinks;
         ListLinks                   m_list_links;
         typedef std::set< InlineImage* >
                                     ListImages;
         ListImages                  m_list_images;
-        int                         m_max_thumbnail_width;
+        int                         m_max_thumbnail_width{ 0 };
 
         // ENCHANT SPELLCHECKER
-        EnchantDict*                m_enchant_dict;
-        int                         m_spell_suggest_offset;
+        EnchantDict*                m_enchant_dict{ nullptr };
+        int                         m_spell_suggest_offset{ 0 };
 
     friend class EntryView;
     friend class LinkCheck;
@@ -512,10 +515,10 @@ class TextviewDiary : public Gtk::TextView
                                     m_cursor_xterm;
         const Glib::RefPtr< Gdk::Cursor >*
                                     m_ptr2cursor_last;
-        Link*                       m_link_hovered;
+        Link*                       m_link_hovered{ nullptr };
 
-        bool                        m_flag_size_allocated;
-        bool                        m_flag_set_text_queued;
+        bool                        m_flag_size_allocated{ false };
+        bool                        m_flag_set_text_queued{ false };
 };
 
 } // end of namespace LIFEO
